@@ -13,6 +13,10 @@
 #ifndef CONSOLE_BUILD
     #include <QtWidgets/QApplication>
     #include <QDesktopServices>
+    #include <QTranslator>
+    #include <QLibraryInfo>
+    #include "settings.h"
+    #include "languagechooser.h"
 #endif
 #include <QDir>
 #include <QCommandLineParser>
@@ -28,6 +32,8 @@
 #include "mainpacketreceiver.h"
 
 #ifndef CONSOLE_BUILD
+    #include "panelgenerator.h"
+    #include "packetnetwork.h"
     #include "mainwindow.h"
 #endif
 #define DEBUGMODE 0
@@ -116,6 +122,8 @@ int main(int argc, char *argv[])
 
     bool gatekeeper = false;
 
+    bool force_gui = false;
+    bool panels_only = false;
 
     //Upon first launch, Apple will assign a psn number and
     //pass it as a command line argument.
@@ -144,6 +152,9 @@ int main(int argc, char *argv[])
             gatekeeper = false;
         }
 
+        force_gui = arg2.contains("--gui");
+        panels_only = arg2.contains("--starterpanel");
+
     }
 
 
@@ -165,8 +176,6 @@ int main(int argc, char *argv[])
 
         qRegisterMetaType<Packet>();
 
-
-
         QDEBUG() << "Running command line mode.";
 
         Packet sendPacket;
@@ -179,11 +188,16 @@ int main(int argc, char *argv[])
         QTextStream out(stdout);
 
         QCoreApplication::setApplicationName("Packet Sender");
-        QString versionBuilder = QString("version ") + SW_VERSION;
+        QString versionBuilder = QString("Version ") + SW_VERSION;
         if (QSslSocket::supportsSsl()) {
-            versionBuilder.append(" / SSL version:");
+            versionBuilder.append(" / SSL:");
             versionBuilder.append(QSslSocket::sslLibraryBuildVersionString());
         }
+
+        #ifdef GIT_CURRENT_SHA1
+            versionBuilder.append(" / Commit: " + QString(GIT_CURRENT_SHA1));
+        #endif
+
         QCoreApplication::setApplicationVersion(versionBuilder);
 
         QCommandLineParser parser;
@@ -1006,9 +1020,13 @@ int main(int argc, char *argv[])
 
         //Workaround linux check for those that support xrandr. Does not work for snaps
         //Note that this bug is actually within Qt.
-        if (!isGuiApp()) {
-            printf("\nCannot open display. Try --help to access console app.\n");
-            return -1;
+        if(!force_gui) {
+            if (!isGuiApp()) {
+                printf("\nCannot open display. Try --help to access console app. Try --gui to bypass this check.\n");
+                return -1;
+            }
+        } else {
+            QDEBUG() << "Bypassing GUI check";
         }
 #endif
 #endif
@@ -1016,43 +1034,102 @@ int main(int argc, char *argv[])
 
 #ifndef CONSOLE_BUILD
 
+
         QApplication a(argc, argv);
 
         QDEBUGVAR(args);
 
         qRegisterMetaType<Packet>();
 
+        QTranslator translator, translator_qt, translator_qtbase;
 
-        //Use default OS styling for non-Windows. Too many theme variants.
+        // Locale translation...
+        QString locale = QLocale::system().name().section("", 0, 2);
+        QDEBUGVAR(locale);
 
 
+        if(Settings::needLanguage()) {
+            LanguageChooser lang;
+            lang.exec();
+        }
+
+
+        QString language = Settings::language();
+        if(language == "Spanish") {
+            QDEBUG() << "qt lang loaded" << translator_qt.load(QString("qt_es"), QLibraryInfo::location(QLibraryInfo::TranslationsPath));
+            QDEBUG() << "base lang loaded" << translator_qtbase.load(QString("qtbase_es"), QLibraryInfo::location(QLibraryInfo::TranslationsPath));
+            QDEBUG() << "app lang loaded" << translator.load(":/languages/packetsender_es.qm");
+            QDEBUG() << QApplication::installTranslator(&translator_qt) << QApplication::installTranslator(&translator_qtbase) << QApplication::installTranslator(&translator) ;
+        }
+
+        if(language == "German") {
+            QDEBUG() << "qt lang loaded" << translator_qt.load(QString("qt_de"), QLibraryInfo::location(QLibraryInfo::TranslationsPath));
+            QDEBUG() << "base lang loaded" << translator_qtbase.load(QString("qtbase_de"), QLibraryInfo::location(QLibraryInfo::TranslationsPath));
+            QDEBUG() << "app lang loaded" << translator.load(":/languages/packetsender_de.qm");
+            QDEBUG() << QApplication::installTranslator(&translator_qt) << QApplication::installTranslator(&translator_qtbase) << QApplication::installTranslator(&translator) ;
+        }
+
+        if(language == "French") {
+            QDEBUG() << "qt lang loaded" << translator_qt.load(QString("qt_fr"), QLibraryInfo::location(QLibraryInfo::TranslationsPath));
+            QDEBUG() << "base lang loaded" << translator_qtbase.load(QString("qtbase_fr"), QLibraryInfo::location(QLibraryInfo::TranslationsPath));
+            QDEBUG() << "app lang loaded" << translator.load(":/languages/packetsender_fr.qm");
+            QDEBUG() << QApplication::installTranslator(&translator_qt) << QApplication::installTranslator(&translator_qtbase) << QApplication::installTranslator(&translator) ;
+        }
         QFile file_system(":/packetsender.css");
         QFile file_dark(":/qdarkstyle/style.qss");
 
+        //Use default OS styling for non-Windows. Too many theme variants.
+
         QSettings settings(SETTINGSFILE, QSettings::IniFormat);
         bool useDark = settings.value("darkModeCheck", true).toBool();
-
+        QString styleSheet = "";
         if(useDark) {
             if (file_dark.open(QFile::ReadOnly)) {
-                QString StyleSheet = QLatin1String(file_dark.readAll());
-                a.setStyleSheet(StyleSheet);
+                styleSheet = QLatin1String(file_dark.readAll());
+                a.setStyleSheet(styleSheet);
                 file_dark.close();
             }
         } else {
             if (file_system.open(QFile::ReadOnly)) {
-                QString StyleSheet = QLatin1String(file_system.readAll());
-                a.setStyleSheet(StyleSheet);
+                styleSheet = QLatin1String(file_system.readAll());
+                a.setStyleSheet(styleSheet);
                 file_system.close();
             }
         }
 
+        //panels_only = true;
+        if(panels_only) {
 
-        MainWindow w;
+            QSettings settings(SETTINGSFILE, QSettings::IniFormat);
+
+            bool darkMode = settings.value("darkModeCheck", true).toBool();
+            PanelGenerator::darkMode = darkMode;
+            PanelGenerator::renderOnly = panels_only;
 
 
-        w.show();
+            PacketNetwork packetNetwork;
+            packetNetwork.init();
+            PanelGenerator * gpanel = new PanelGenerator();
+            if(!styleSheet.isEmpty()) {
+                gpanel->setStyleSheet(styleSheet);
+            }
+
+            QDEBUG() << " packet send connect attempt:" << QObject::connect(gpanel, SIGNAL(sendPacket(Packet)),
+                     &packetNetwork, SLOT(packetToSend(Packet)));
+
+            gpanel->initAutoLaunchOrEditMode();
+            gpanel->show();
+            return a.exec();
+
+        } else {
+
+            MainWindow w;
+            w.show();
+            return a.exec();
+
+        }
+
 
-        return a.exec();
 
 #endif
 
