@@ -14,6 +14,7 @@
 
 #ifndef CONSOLE_BUILD
 #include "ui_settings.h"
+#include "languagechooser.h"
 
 #include <QDesktopServices>
 #include <QFileDialog>
@@ -37,6 +38,47 @@ const QString Settings::ERROR_STR = "Error";
 
 
 
+QString Settings::logHeaderTranslate(QString txt)
+{
+    if(txt == "Send") {
+        return QObject::tr("Send");
+    }
+    if(txt == "Name") {
+        return QObject::tr("Name");
+    }
+    if(txt == "Resend") {
+        return QObject::tr("Resend");
+    }
+    if(txt == "To Address") {
+        return QObject::tr("To Address");
+    }
+    if(txt == "To Port") {
+        return QObject::tr("To Port");
+    }
+    if(txt == "Method") {
+        return QObject::tr("Method");
+    }
+    if(txt == "Request Path") {
+        return QObject::tr("Request Path");
+    }
+    if(txt == "Time") {
+        return QObject::tr("Time");
+    }
+    if(txt == "From IP") {
+        return QObject::tr("From IP");
+    }
+    if(txt == "From Port") {
+        return QObject::tr("From Port");
+    }
+    if(txt == "Error") {
+        return QObject::tr("Error");
+    }
+
+    return txt;
+
+}
+
+
 const QString Settings::ALLHTTPSHOSTS = "HTTPHeaderHosts";
 const QString Settings::HTTPHEADERINDEX = "HTTPHeader:";
 
@@ -58,7 +100,7 @@ Settings::Settings(QWidget *parent) :
     QSettings settings(SETTINGSFILE, QSettings::IniFormat);
 
     QIcon mIcon(":pslogo.png");
-    setWindowTitle("Packet Sender Settings");
+    setWindowTitle("Packet Sender "+tr("Settings"));
     setWindowIcon(mIcon);
 
     //this is no longer working thanks to faster traffic log
@@ -69,7 +111,6 @@ Settings::Settings(QWidget *parent) :
     loadCredentialTable();
     on_genAuthCheck_clicked(false);
 
-
     //smart responses...
     ui->smartResponseEnableCheck->setChecked(settings.value("smartResponseEnableCheck", false).toBool());
 
@@ -123,6 +164,34 @@ Settings::Settings(QWidget *parent) :
     ui->sslLocalCertificatePath->setText(settings.value("sslLocalCertificatePath", "").toString());
     ui->sslPrivateKeyPath->setText(settings.value("sslPrivateKeyPath", "").toString());
 
+    ui->dateFormat->setText(settings.value("dateFormat", "yyyy-MM-dd").toString());
+    ui->timeFormat->setText(settings.value("timeFormat", "hh:mm:ss ap").toString());
+
+    QDateTime now = QDateTime::currentDateTime();
+    QString dateFormat = ui->dateFormat->text();
+    QString timeFormat = ui->timeFormat->text();
+
+    ui->dateFormatExample->setText(now.toString(dateFormat));
+    ui->timeFormatExample->setText(now.toString(timeFormat));
+
+
+    connect(ui->dateFormat, &QLineEdit::textChanged, this, [=](QString val) {
+        // use action as you wish
+        QDateTime now = QDateTime::currentDateTime();
+        QString dateFormat = ui->dateFormat->text();
+        ui->dateFormatExample->setText(now.toString(dateFormat));
+    });
+
+
+    connect(ui->timeFormat, &QLineEdit::textChanged, this, [=](QString val) {
+        // use action as you wish
+        QDateTime now = QDateTime::currentDateTime();
+        QString timeFormat = ui->timeFormat->text();
+        ui->timeFormatExample->setText(now.toString(timeFormat));
+    });
+
+
+
     ui->restoreSessionCheck->setChecked(settings.value("restoreSessionCheck", true).toBool());
     ui->checkforUpdates->setChecked(settings.value("checkforUpdates", true).toBool());
 
@@ -229,6 +298,37 @@ Settings::~Settings()
 }
 
 
+bool Settings::needLanguage()
+{
+    //Return true if language was never chosen
+    QSettings settings(SETTINGSFILE, QSettings::IniFormat);
+    QString language = settings.value("languageCombo", "").toString().toLower();
+
+    return language.isEmpty();
+}
+
+QString Settings::language()
+{
+
+    QString locale = QLocale::system().name().section("", 0, 2);
+    QDEBUGVAR(locale);
+    QSettings settings(SETTINGSFILE, QSettings::IniFormat);
+    QString language = settings.value("languageCombo", "English").toString().toLower();
+    if(language.contains("spanish")) {
+        return "Spanish";
+    }
+
+    if(language.contains("german")) {
+        return "German";
+    }
+
+    if(language.contains("french")) {
+        return "French";
+    }
+
+    return "English";
+}
+
 
 void Settings::statusBarMessage(QString msg)
 {
@@ -252,11 +352,11 @@ void Settings::on_buttonBox_accepted()
         } else {
 
             QMessageBox msgBox;
-            msgBox.setWindowTitle("Bad IP.");
+            msgBox.setWindowTitle(tr("Bad IP."));
             msgBox.setStandardButtons(QMessageBox::Ok);
             msgBox.setDefaultButton(QMessageBox::Ok);
             msgBox.setIcon(QMessageBox::Warning);
-            msgBox.setText("Packet Sender cannot bind invalid IP "+ ui->bindIPAddress->text());
+            msgBox.setText(tr("Packet Sender cannot bind invalid IP ")+ ui->bindIPAddress->text());
             msgBox.exec();
             return;
         }
@@ -270,11 +370,11 @@ void Settings::on_buttonBox_accepted()
 
             if(t == s) {
                 QMessageBox msgBox;
-                msgBox.setWindowTitle("TCP and SSL non-zero port conflict.");
+                msgBox.setWindowTitle(tr("TCP and SSL non-zero port conflict."));
                 msgBox.setStandardButtons(QMessageBox::Ok);
                 msgBox.setDefaultButton(QMessageBox::Ok);
                 msgBox.setIcon(QMessageBox::Warning);
-                msgBox.setText("Packet Sender cannot bind TCP and SSL to the same port.");
+                msgBox.setText(tr("Packet Sender cannot bind TCP and SSL to the same port."));
                 msgBox.exec();
                 return;
             }
@@ -318,6 +418,9 @@ void Settings::on_buttonBox_accepted()
 
     settings.setValue("checkforUpdates", ui->checkforUpdates->isChecked());
 
+    settings.setValue("dateFormat", ui->dateFormat->text());
+    settings.setValue("timeFormat", ui->timeFormat->text());
+
 
     settings.setValue("copyUnformattedCheck", ui->copyUnformattedCheck->isChecked());
     settings.setValue("rolling500entryCheck", ui->rolling500entryCheck->isChecked());
@@ -327,7 +430,6 @@ void Settings::on_buttonBox_accepted()
     settings.setValue("persistentTCPCheck", ui->persistentTCPCheck->isChecked());
     settings.setValue("translateMacroSendCheck", ui->translateMacroSendCheck->isChecked());
 
-
     settings.setValue("autolaunchStarterPanelButton", ui->autolaunchStarterPanelButton->isChecked());
     settings.setValue("darkModeCheck", ui->darkModeCheck->isChecked());
     settings.setValue("httpAdjustContentTypeCheck", ui->httpAdjustContentTypeCheck->isChecked());
@@ -355,14 +457,14 @@ void Settings::on_buttonBox_accepted()
     QStringList packetSavedHeaderNow;
     packetSavedHeaderNow.clear();
     for (int i = 0; i < lw->count(); i++) {
-        packetSavedHeaderNow.append(lw->item(i)->text());
+        packetSavedHeaderNow.append(lw->item(i)->data(Qt::UserRole).toString());
     }
     settings.setValue("packetSavedTableHeaders", packetSavedHeaderNow);
 
 
     packetSavedHeaderNow.clear();
     for (int i = 0; i < lwTraffic->count(); i++) {
-        packetSavedHeaderNow.append(lwTraffic->item(i)->text());
+        packetSavedHeaderNow.append(lwTraffic->item(i)->data(Qt::UserRole).toString());
     }
     settings.setValue("packetTableHeaders", packetSavedHeaderNow);
 
@@ -551,7 +653,8 @@ void Settings::loadTableHeaders()
     ui->displayOrderListTraffic->clear();
 
     foreach (tempString, packetSavedTableHeaders) {
-        tItem = new QListWidgetItem(tempString);
+        tItem = new QListWidgetItem(logHeaderTranslate(tempString));
+        tItem->setData(Qt::UserRole, tempString);
         tItem->setIcon(QIcon(UPDOWNICON));
         ui->displayOrderList->addItem(tItem);
     }
@@ -559,7 +662,8 @@ void Settings::loadTableHeaders()
     ui->displayOrderList->setCursor(Qt::CrossCursor);
 
     foreach (tempString, packetTableHeaders) {
-        tItem = new QListWidgetItem(tempString);
+        tItem = new QListWidgetItem(logHeaderTranslate(tempString));
+        tItem->setData(Qt::UserRole, tempString);
         tItem->setIcon(QIcon(UPDOWNICON));
         ui->displayOrderListTraffic->addItem(tItem);
     }
@@ -572,7 +676,6 @@ void Settings::loadTableHeaders()
     ui->displayOrderListTraffic->setAlternatingRowColors(true);
 }
 
-
 void Settings::on_responsePacketBox_currentIndexChanged(const QString &arg1)
 {
 
@@ -865,7 +968,7 @@ void Settings::loadCredentialTable()
         }
     }
 
-    QStringList tableHeaders = {"Host", "Key", "Value"};
+    QStringList tableHeaders = {tr("Host"), tr("Key"), tr("Value")};
     ui->httpCredentialTable->verticalHeader()->show();
     ui->httpCredentialTable->horizontalHeader()->show();
     ui->httpCredentialTable->setHorizontalHeaderLabels(tableHeaders);
@@ -930,14 +1033,26 @@ void Settings::on_httpCredentialTable_itemChanged(QTableWidgetItem *item)
 void Settings::on_genAuthCheck_clicked(bool checked)
 {
     if(ui->genAuthCheck->isChecked()) {
-        ui->httpKeyLabel->setText("UN/ClientID");
-        ui->httpValueLabel->setText("PW/Access");
-        ui->addCredentialButton->setText("HTTP Auth Header");
+        ui->httpKeyLabel->setText(tr("UN/ClientID"));
+        ui->httpValueLabel->setText(tr("PW/Access"));
+        ui->addCredentialButton->setText(tr("HTTP Auth Header"));
     } else {
-        ui->httpKeyLabel->setText("Key");
-        ui->httpValueLabel->setText("Value");
-        ui->addCredentialButton->setText("HTTP Header");
+        ui->httpKeyLabel->setText(tr("Key"));
+        ui->httpValueLabel->setText(tr("Value"));
+        ui->addCredentialButton->setText(tr("HTTP Header"));
     }
 
 }
 #endif
+
+void Settings::on_chooseLanguageButton_clicked()
+{
+
+#ifndef CONSOLE_BUILD
+    LanguageChooser * lang = new LanguageChooser(this);
+    lang->exec();
+
+#endif
+
+}
+
